# ActivitiesSummaryV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30Rc2**](LastModifiedDateV30Rc2.md) |  | [optional] 
**distinctions** | [**DistinctionsSummaryV30Rc2**](DistinctionsSummaryV30Rc2.md) |  | [optional] 
**educations** | [**EducationsSummaryV30Rc2**](EducationsSummaryV30Rc2.md) |  | [optional] 
**employments** | [**EmploymentsSummaryV30Rc2**](EmploymentsSummaryV30Rc2.md) |  | [optional] 
**fundings** | [**FundingsV30Rc2**](FundingsV30Rc2.md) |  | [optional] 
**invited_positions** | [**InvitedPositionsV30Rc2**](InvitedPositionsV30Rc2.md) |  | [optional] 
**memberships** | [**MembershipsV30Rc2**](MembershipsV30Rc2.md) |  | [optional] 
**peer_reviews** | [**PeerReviewsV30Rc2**](PeerReviewsV30Rc2.md) |  | [optional] 
**qualifications** | [**QualificationsV30Rc2**](QualificationsV30Rc2.md) |  | [optional] 
**research_resources** | [**ResearchResourcesV30Rc2**](ResearchResourcesV30Rc2.md) |  | [optional] 
**services** | [**ServicesV30Rc2**](ServicesV30Rc2.md) |  | [optional] 
**works** | [**WorksSummaryV30Rc2**](WorksSummaryV30Rc2.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

